==> owncloud-8.2.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/cs_CZ.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivita",
    "Personal activity feed for %s" : "Přehled aktivit uživatele %s",
    "Your feed URL is invalid" : "URL adresa kanálu není platná",
    "Your settings have been updated." : "Vaše nastavení bylo aktualizováno.",
    "Mail" : "Pošta",
    "Stream" : "Proud",
    "Activities" : "Aktivity",
    "Error loading activities" : "Chyba načtení aktivit",
    "No activities" : "Žádné aktivity",
    "This stream will show events like additions, changes & shares" : "Datový proud bude zobrazovat události jako přidání, změny a sdílení",
    "There are no events for this filter" : "Pro tato kritéria nejsou žádné události",
    "Activity notification" : "Upozornění na aktivity",
    "All Activities" : "Všechny aktivity",
    "Activities by you" : "Vlastní aktivity",
    "Activities by others" : "Aktivity ostatních",
    "\"remote user\"" : "\"vzdálený uživatel\"",
    "in %s" : "v %s",
    "%s and %s" : "%s a %s",
    ", " : ", ",
    "_%s and <strong %s>%n more</strong>_::_%s and <strong %s>%n more</strong>_" : ["%s a <strong %s>%n další</strong>","%s a <strong %s>%n další</strong>","%s a <strong %s>%n dalších</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s a %n další","%s a %n další","%s a %n dalších"],
    "Hello %s," : "Vítejte %s,",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* a %n další ","* a %n další ","* a %n dalších "],
    "Notifications" : "Upozornění",
    "List your own actions in the stream" : "Zobrazovat vlastní činnosti v seznamu",
    "Notify about your own actions via email" : "Posílat oznámení o vlastních činnostech emailem",
    "You need to set up your email address before you can receive notification emails." : "Pokud chcete dostávat upozornění emailem, musíte nejprve nastavit svou emailovou adresu.",
    "Send emails:" : "Posílat emaily:",
    "Hourly" : "Každou hodinu",
    "Daily" : "Denně",
    "Weekly" : "Týdně",
    "Activity feed" : "Přehled aktivit",
    "Enable RSS feed" : "Povolit RSS kanál",
    "No activity yet" : "Zatím bez aktivity",
    "No more events to load" : "Žádné další události k načtení",
    "Files" : "Soubory",
    "_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_" : ["%s a <strong class=\"has-tooltip\" title=\"%s\">%n další</strong>","%s a <strong class=\"has-tooltip\" title=\"%s\">%n další</strong>","%s a <strong class=\"has-tooltip\" title=\"%s\">%n dalších</strong>"]
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> owncloud-9.0.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/cs_CZ.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivita",
    "Personal activity feed for %s" : "Přehled aktivit uživatele %s",
    "Your feed URL is invalid" : "URL adresa kanálu není platná",
    "Your settings have been updated." : "Vaše nastavení bylo aktualizováno.",
    "Mail" : "Pošta",
    "Stream" : "Proud",
    "Activities" : "Aktivity",
    "Error loading activities" : "Chyba načtení aktivit",
    "No activities" : "Žádné aktivity",
    ", " : ", ",
    "{parameterList} and {lastParameter}" : "{parameterList} a {lastParameter}",
    "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} a {linkStart}%n další{linkEnd}","{parameterList} a {linkStart}%n další{linkEnd}","{parameterList} a {linkStart}%n dalších{linkEnd}"],
    "in {directory}" : "v {directory}",
    "This stream will show events like additions, changes & shares" : "Datový proud bude zobrazovat události jako přidání, změny a sdílení",
    "There are no events for this filter" : "Pro tato kritéria nejsou žádné události",
    "Today" : "Dnes",
    "Yesterday" : "Včera",
    "\"remote user\"" : "\"vzdálený uživatel\"",
    "Activity notification" : "Upozornění na aktivity",
    "All Activities" : "Všechny aktivity",
    "Activities by you" : "Vlastní aktivity",
    "Activities by others" : "Aktivity ostatních",
    "%s and %s" : "%s a %s",
    "Hello %s," : "Vítejte %s,",
    "You are receiving this email because the following things happened at %s" : "Dostali jste tento email, protože došlo k následujícím změnám na %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* a %n další ","* a %n další ","* a %n dalších "],
    "List your own actions in the stream" : "Zobrazovat vlastní činnosti v seznamu",
    "Notify about your own actions via email" : "Posílat oznámení o vlastních činnostech emailem",
    "You need to set up your email address before you can receive notification emails." : "Pokud chcete dostávat upozornění emailem, musíte nejprve nastavit svou emailovou adresu.",
    "Send emails:" : "Posílat emaily:",
    "Hourly" : "Každou hodinu",
    "Daily" : "Denně",
    "Weekly" : "Týdně",
    "Activity feed" : "Přehled aktivit",
    "Enable RSS feed" : "Povolit RSS kanál",
    "No activity yet" : "Zatím bez aktivity",
    "No more events to load" : "Žádné další události k načtení",
    "Files" : "Soubory"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
